"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var ReactDOM = require("react-dom");
var _ = require("underscore");
var uiHelpers_1 = require("./../../utilities/uiHelpers");
var classNames_1 = require("../../utilities/classNames");
var Grid = (function (_super) {
    tslib_1.__extends(Grid, _super);
    function Grid() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Grid.prototype.render = function () {
        var originalClassName = this.props.className;
        var attrs = _.omit(this.props, "className", "debugMode", "disableFlexOverride", "table", "fillContainer", "tagName");
        var classes = classNames_1.ClassHelpers.classNames(originalClassName, "grid", {
            "fill-container": this.props.fillContainer,
            "grid-debug": this.props.debugMode,
            "table-grid": this.props.table
        });
        if (this.props.fillContainer && !this.props.disableFlexOverride) {
            return React.createElement(this.props.tagName || "div", { className: "flex-override" }, React.createElement("div", tslib_1.__assign({}, attrs, { className: classes })));
        }
        else {
            return React.createElement(this.props.tagName || "div", tslib_1.__assign({}, attrs, { className: classes }));
        }
    };
    Grid.prototype.componentDidMount = function () {
        if (this.props.fillContainer && !this.props.disableFlexOverride) {
            ReactDOM.findDOMNode(this).parentElement.style.position = "relative";
        }
    };
    return Grid;
}(React.Component));
exports.Grid = Grid;
var Row = (function (_super) {
    tslib_1.__extends(Row, _super);
    function Row() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Row.prototype.needsFixed = function () {
        if (!this.props.height) {
            return false;
        }
        if (typeof this.props.height === "number") {
            return true;
        }
        else {
            if (this.props.height === "auto") {
                return true;
            }
        }
        return false;
    };
    Row.prototype.render = function () {
        var attrs = _.omit(this.props, "className", "height", "tagName");
        var classes = classNames_1.ClassHelpers.classNames(this.props.className, "row", this.needsFixed() ? "no-flex" : "");
        var styles = this.props.style;
        var colStyles;
        if (this.props.height) {
            if (typeof this.props.height === "number") {
                styles = _.extend({ height: this.props.height + "px" }, styles);
            }
            else {
                var hString = this.props.height;
                var starIndex = hString.indexOf('*');
                if (this.props.height === "auto") {
                }
                else if (starIndex !== -1 && parseFloat(hString)) {
                    var hString_1 = this.props.height;
                    var spans = hString_1.substr(0, starIndex);
                    styles = _.extend({ flex: "" + spans }, styles);
                }
                else {
                    throw new Error("Unsupported height property '" + this.props.height + "' on Grid Row. If you are using a string, make sure it is either 'auto' or follows the pattern '[number]*'");
                }
            }
        }
        return React.createElement(this.props.tagName || "div", tslib_1.__assign({}, attrs, { className: classes, style: styles }), React.Children.map(this.props.children, function (c) {
            return c ? React.cloneElement(c, { style: colStyles ? _.extend(colStyles, c.props.style) : c.props.style }) : null;
        }));
    };
    return Row;
}(React.Component));
exports.Row = Row;
var Col = (function (_super) {
    tslib_1.__extends(Col, _super);
    function Col() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Col.prototype.needsFixed = function () {
        if (!this.props.width) {
            return false;
        }
        if (typeof this.props.width === "number") {
            return true;
        }
        else {
            if (this.props.width === "auto") {
                return true;
            }
        }
        return false;
    };
    Col.prototype.render = function () {
        var alignmentClasses = uiHelpers_1.LayoutHelpers.GetAlignmentClasses(this.props.verticalAlignment, this.props.horizontalAlignment);
        var classes = classNames_1.ClassHelpers.classNames("col", this.props.className, alignmentClasses, {
            "no-flex": this.needsFixed(),
        });
        var attrs = _.omit(this.props, "className", "width", "horizontalAlignment", "verticalAlignment", "tagName");
        var styles = this.props.style;
        if (this.props.width) {
            if (typeof this.props.width === "number") {
                styles = _.extend({ maxwidth: this.props.width + "px", width: "100%" }, styles);
            }
            else {
                var wString = this.props.width;
                var starIndex = wString.indexOf('*');
                if (this.props.width === "auto") {
                }
                else if (starIndex !== -1 && parseFloat(wString)) {
                    var spans = wString.substr(0, starIndex);
                    styles = _.extend({ flex: "" + spans }, styles);
                }
                else {
                    throw new Error("Unsupported width property '" + this.props.width + "' on Grid > Row > Col. If you are using a string, make sure it is either 'auto' or follows the pattern '[number]*'");
                }
            }
        }
        if (typeof this.props.width === "number") {
            styles = _.extend({ maxWidth: this.props.width + "px", width: "100%" }, styles);
        }
        return React.createElement(this.props.tagName || "div", tslib_1.__assign({}, attrs, { className: classes, style: styles }));
    };
    return Col;
}(React.Component));
exports.Col = Col;
